<p align="left">
  <img src="./logo/logo.png" width="350" title="CWInPy logo">
</p>

# CW Inference in Python

A Python module for performing Bayesian inference on continuous gravitational-wave signals from pulsars

* [Documentation](https://cwinpy.readthedocs.io)

[![Documentation Status](https://readthedocs.org/projects/cwinpy/badge/?version=latest)](https://cwinpy.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://github.com/cwinpy/cwinpy/workflows/build/badge.svg)](https://github.com/cwinpy/cwinpy/actions?query=workflow%3Abuild)
[![codecov](https://codecov.io/gh/cwinpy/cwinpy/branch/master/graph/badge.svg)](https://codecov.io/gh/cwinpy/cwinpy)
[![PyPI version](https://badge.fury.io/py/cwinpy.svg)](https://badge.fury.io/py/cwinpy)
[![Anaconda-Server Badge](https://anaconda.org/conda-forge/cwinpy/badges/version.svg)](https://anaconda.org/conda-forge/cwinpy)
